#
# spec file for package argyllcms
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _udevrulesdir %(pkg-config --variable=udevdir udev)/rules.d

%define archivename Argyll_V%{version}%{?alphaversion}_src.zip

Name:           argyllcms
Version:        1.6.3
Release:        7.4
Summary:        ICC compatible color management system
License:        AGPL-3.0 and GPL-2.0+ and MIT
Group:          System/X11/Utilities

Url:            http://www.%{name}.com/

Source0:        %{url}%{archivename}
Source1:        19-color.fdi
Source2:        color-device-file.policy
Source3:        ajam-2.5.2-1.3.3.tgz
Source99:       argyllcms.changes
# drop udev-acl stuff, handled by udev directly (Mandriva)
Patch5:         argyllcms-udev151.patch
Patch7:         ajam-include.patch
Patch8:         argyllcms-1.4.0-warnings.patch
# PATCH-FIX-UPSTREAM argyllcms-udev-builtin.patch fcrozat@suse.com -- usb-db is now builtin in udev
Patch9:         argyllcms-udev-builtin.patch
# PATCH-FIX-UPSTREAM argyllcms-udev-hwdb.patch fcrozat@suse.com -- usb-db is replaced by hwdb in recent udev
Patch10:        argyllcms-udev-hwdb.patch
# PATCH-FIX-UPSTREAM argyllcms-decl.patch sbrabec@suse.cz -- Add missing headers.
Patch12:        argyllcms-decl.patch

BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  unzip
BuildRequires:  xorg-x11-devel
#needed for ajam
BuildRequires:  bison
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  pkgconfig(udev)
Requires:       udev
%if 0%{?suse_version} < 1120
BuildRequires:  hal
Requires:       hal
%endif
# FIXME: The application dlopens libcolordcompat.so, which does not
# exists in openSUSE colord package. We should use Suggests
# or Recommends here, and change its name in the source code
# to not read file from colord-devel.

%description
The Argyll color management system supports accurate ICC profile creation for
scanners, CMYK printers, film recorders and calibration and profiling of
displays.

Spectral sample data is supported, allowing a selection of illuminants observer
types, and paper fluorescent whitener additive compensation. Profiles can also
incorporate source specific gamut mappings for perceptual and saturation
intents. Gamut mapping and profile linking uses the CIECAM02 appearance model,
a unique gamut mapping algorithm, and a wide selection of rendering intents. It
also includes code for the fastest portable 8 bit raster color conversion
engine available anywhere, as well as support for fast, fully accurate 16 bit
conversion. Device color gamuts can also be viewed and compared using a VRML
viewer.

%package doc
Summary:        Argyll CMS documentation
Group:          System/X11/Utilities
# Does not really make sense without Argyll CMS itself
Requires:       %{name} = %{version}

%description doc
The Argyll color management system supports accurate ICC profile creation for
scanners, CMYK printers, film recorders and calibration and profiling of
displays.

This package contains the Argyll color management system documentation.

%prep
%setup -q -n Argyll_V%{version}
%if 0%{?suse_version} >= 1120
%patch5 -p1 -b .udev151
%if 0%{?suse_version} >= 1220
%if 0%{?suse_version} >= 1310
%patch10 -p1 -b .hwdb
%else
%patch9 -p1 -b .builtin
%endif
%endif
%endif
%patch8 -p1 -b .warnings
%patch12 -p1

tar xf %{SOURCE3}
cd ajam-2.5.2-1.3.3
%patch7 -p1 -b .include
cd ..

# remove unused source code
rm -fr usb/{*.inf,*.rtf,*.inf,*.cat,*.vcproj,*.sys,*.dsw,*.sln,*.dsp,*template*,WinCo*,winsub*,*kext*,KDRIVER_LICENSE,README_MSVC.txt,msvc,*.cmd,bin,driver,binfiles.*}

%build
cd ajam-2.5.2-1.3.3
make CFLAGS="-std=gnu89 ${RPM_OPT_FLAGS}"
ln -s $PWD/bin.unix/jam ../jam
cd ..

echo "CCFLAGS += -std=gnu89 ${RPM_OPT_FLAGS} -fno-strict-aliasing ;" >> Jamtop
# Evil hack to get --as-needed working. The build system unfortunately lists all
# the shared libraries by default on the command line _before_ the object to be built...
echo "STDLIBS += -ldl -lrt -lX11 -lXext -lXxf86vm -lXinerama -lXrandr -lXau -lXdmcp -lXss -ltiff -ljpeg ;" >> Jamtop

./jam  -fJambase %{?_smp_mflags}

%install
./jam -q -fJambase install

rm bin/License.txt

mkdir -p $RPM_BUILD_ROOT/{%{_bindir},%{_datadir}/color/argyll/ref}

install -m 0755 -D bin/* $RPM_BUILD_ROOT/%{_bindir}

install -m 0644 -D ref/*  %{buildroot}/%{_datadir}/color/argyll/ref
rm -f $RPM_BUILD_ROOT/%{_datadir}/color/argyll/License.txt

# ensure timestamp is shipped files is not changing for each rebuild (boo#916158)
TIMESTAMP=$(LC_ALL=C date -r %{SOURCE99} +%c)

sed -i -e 's/^CREATED .*/CREATED "$TIMESTAMP"/g' %{buildroot}%{_datadir}/color/argyll/ref/RefMediumGamut.gam

%if 0%{?suse_version} < 1120
# Do some device permission magic
install -d -m 0755 %{buildroot}%{_datadir}/hal/fdi/policy/10osvendor/
install -p -m 0644 %{SOURCE1} \
         %{buildroot}%{_datadir}/hal/fdi/policy/10osvendor/

install -d -m 0755 %{buildroot}%{_datadir}/PolicyKit/policy/
install -p -m 0644 %{SOURCE2} \
        %{buildroot}%{_datadir}/PolicyKit/policy/
%else
install -d -m 0755 %{buildroot}%{_udevrulesdir}
install -p -m 0644 usb/55-Argyll.rules \
        %{buildroot}%{_udevrulesdir}
%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc *.txt

%{_bindir}/*
%dir %{_datadir}/color
%{_datadir}/color/argyll

%if 0%{?suse_version} < 1120
%{_datadir}/hal/fdi/policy/10osvendor/19-color.fdi
%{_datadir}/PolicyKit/policy/color-device-file.policy
%else
%{_udevrulesdir}/55-Argyll.rules
%endif

%files doc
%defattr(-,root,root,-)
%doc doc/*.html doc/*.jpg doc/*.txt

%changelog
* Tue Feb 24 2015 rguenther@suse.com
- Use -std=gnu89 for building to not run into broken __declspec
  uses with the GCC 5 default of -std=gnu99.
* Mon Feb 23 2015 meissner@suse.com
- allow building with udev-mini by using pkgconfig(udev)
* Mon Feb 23 2015 meissner@suse.com
- do not rpm -q udev
* Wed Feb  4 2015 fcrozat@suse.com
- Add argyllcms.changes to Source, used to compute timestamp
- Use a stable timestamp for generated files (boo#916158), ensuring
  build is reproducible.
* Mon Jan 26 2015 fcrozat@suse.com
- Move reference files to /usr/share/argyll/ref, expected path from
  gnome-color-manager (bsc#914679).
* Fri Jan 31 2014 fcrozat@suse.com
- Release 1.6.3:
  + Added ProPhoto.icm and ProPhotoLin.icm to ref profiles.
  + Fix bug in xicclu -py conversion.
  + Added code to minimize ICC rounding error on matrix profile
    white point accuracy. Re-generated all reference profiles with
    this change.
  + Changed i1d3 driver to completely ignore any EEPROM checksum
    errors for non "A-01" rev. instruments.
  + Made transplot handle RGB->RGB device link.
  + Removed colprof -y option. Use "profcheck -v2" instead, as it
    is more developed.
  + Fixed bug in dispcal - it was not using the final measurement
    pass to update the calibration curves.
  + Fixed bug in spotread, dispcal & dispread for CCSS capable
    instruments where refresh display types was being ignored if a
    custom observer was used, and/or the custom observer as being
    ignored, and/or a  CCMX was being ignored.
  + Renamed verify to colverify to avoid clash with MSWin program
    of the same name. Made it print the patch location for -v2 if
    it is present in the file.
  + Changed targen to ensure that -V and -p options effects are
    reflected in the resulting expected CIE values of the .ti1
    file.
  + Changed targen so that -V parameter also affects single
    channel, grey wedge, grid & body centered grid point
    distribution.
  + Changed colprof to deal with variable grid distribution in a
    more neuanced way, to reduce overshoot artifacts when the -V
    parameter is used.
  + Changed colprof to used a power_like function for the grid
    distribution shape from the -V parameter, so as to avoid issues
    with a power curve infinte slope near zero.
  + Changed colprof to used a scaled down value of the targen -V
    parameter as the default for its -V parameter.
  + Added a special case to collink for RGB video input encoding to
    (attempt) to fine tune the black point to compensate for it
    (probably) not falling on a cLUT grid point. & out encoding.
  + Tweaked dispcal to try and improve accuracy of black point
    calibration.
  + Switch dispread to use NoClamp readings, so that average black
    point value is not biased.
  + Fixed bug introduced into 1.6.2 oeminst that prevents .ccss
    files being installed.
* Fri Dec 20 2013 fcrozat@suse.com
- Release 1.6.2:
  + Added "dark region emphasis" -V parameter to targen and colprof.
  + Fixed bug and tweaked dispcal black point optimization to err on
  the black side. Added -v3 for even more debugging information.
  + Changed i1d3 driver to be more forgiving of EEProm checksum
  calculation (support for ""A-02"" release).
  + Fixed problem with TV encoded output and dispread -E -k/-K.
  + Fixed minor bug in DE94 in icclib.
  + Fixed major bug in illumread - result was being corrupted.
  + Fixed "edges don't match" bug in printarg when -iCM -h -s/-S
  used.
  + Fix bug in -H flag in ccxxmake, chartread, dispcal, dispread,
  illumread & spotread so that it works once again.
- Bugfix update from 1.6.1:
  + Fix bug in "average -m"
  + Fix oeminst to work with a wider range of i1d3 install files.
  + Fix ColorMunki reflective measurement accuracy, particularly for
  reflective readings.
- Remove argyllcms-stringcompare.patch, argyllcms-void.patch:
  merged upstream.
* Tue Aug 20 2013 sbrabec@suse.cz
- Release 1.6.0:
  + Added support for JETI specbos 1211 and 1201.
  + Added Video profiling & 3dLut creation support for eeColor and
    MadVR.
  + Linux profile installation will use colord.
  + Fix ColorHug driver.
  + Changed instlib API ambient XYZ and spectral units to Lux.
  + For those instruments that support it, made ambient readings
    honor refresh mode measurements.
  + Changed spotread -ew mode to be Bradford chromatic transform
    rather than XYZ scaling.
  + Added support to xicclu to lookup colors though CAL files.
  + Added -Y R:rate option to spotread, dispcal, dispread &
    ccxxmake.
  + By default printtarg will create PS and EPS files with a CUPS
    job ticket to disable color management.
  + Added display update delay calibration support to i1pro and
    ColorMunki.
  + Changed dispcal & dispread so that they wait up to 0.5 seconds
    when reading dark patches after light ones to allow for display
    fall time.
  + Changed dispwin daemon loader mode option from -E to -X.
  + Changed dispcal verify option from -E to -z.
  + Added -E option to to dispread to encode test patch colors in
    Video 16-235 range.
  + Changed CIECAM02 Flare model to distinguish between Flare from
    the image itself, and Glare from ambient light.
  + Improved i1pro hi-res mode to improve accuracy.
  + Added Body Centered Cubic grid option to targen.
  + Added -Yn flag to dispcal and dispread.
  + Improve robustness of i1d3 display update measurement code.
  + Added support for applying calibration curves in collink.
  + Changed spotread so that it won't fall back to emissive spot
    mode if an ambient reading is requested.
  + Turned off B2A table clip map smoothing.
  + Fixed crash in ucmm/ucmm.c when loading certain profiles using
    dispwin.
  + Fixed gamut mapping intent "rl" to really use relative L*a*b*
  + Fix bug in cicam02 in V1.5.0 that causes some mapping problems
    in the red for collink -ir or -ila.
  + Changed cctiff so that it does lossless JPEG copy when there is
    no color transformation
  + Fix xicclu so that it works with device links.
  + Fixed bug in shaper/matrix profile curves that caused random
    bumpy black behaviour.
  + Don't add colorant tag to .tiff files in cctiff unless it is a
    non-standard space, as Photoshop will barf on such files.
  + Fix bug with Spyder not being able to break out of dispcal
    adjustment loop.
  + Fix bug in xicc/xicclu, -K flag not being recognised.
  + Fix bug in xicc/xmatrix.c introduced that prevents matrix only
    profiles from being created.
  + libusb 1.0 is now deprecated in favor of native USB drivers.
* Wed Jul 31 2013 fcrozat@suse.com
- Release 1.5.1:
  + Many bug fixes
  + add support for i1pro Rev E (i1pro2)
  + improved support for ColorMunki and i1pro
  + spotread can interactively query refresh rate
  + spyd2en, spyd4en and i1d3ccss was been merged in one tool named
    oeminst.
  + No longer uses libusb, talk directly to USB device through
    kernel devices.
  + Add support for ColorCheckerPassport in scanin.
  + -V (adaptative mode) is deprecated in dispcal, dispread and
    ccxxmake, since it is the default. Use -ZA flag to disable.
  + ColorHug support is enabled by default.
  + Added automatic adjustement of patch reading for i1d3.
- Drop argyllcms-fixbuild.patch (merged)
- Rename argyllcms-1.3.0-udev151.patch to argyllcms-udev151.patch.
- Add argyllcms-udev-builtin.patch for udev usb-db builtin
  (openSUSE 12.2/12.3) and argyllcms-udev-hwdb.patch (openSUSE 13.1
  and later) for udev hwdb.
- Update argyllcms-1.4.0-warnings.patch (partially merged)
- Drop SG_header.txt, merged upstream.
* Thu Oct 18 2012 fcrozat@suse.com
- Fix build with new udev rules directory location.
* Fri Oct 12 2012 coolo@suse.com
- replace jam with ./jam
* Tue Jun 26 2012 fcrozat@suse.com
- Add new upstream version of SG_header.txt, to prevent any legal
  misunderstanding (bnc#768826).
* Mon Jun 25 2012 fcrozat@suse.com
- Release 1.4.0:
  + various bug fixes
  + add support for ICC profiles in embedded JPEG
  + fix CVE-2012-1616 (bnc#768322)
- drop autotools patches, switch back to original Jam based build
- add ajam (argyll patched version of Jam, BSD-license) to source
  package (needed only for build)
- drop shared libraries and corresponding subpackages, not used by
  anything.
- drop cologhug patch, merged upstream.
- Add argyllcms-fixbuild.patch: fix build with system tiff/jpeg
  libraries
- Add ajam-include.patch: add missing headers
- Add argyllcms-1.4.0-warnings.patch: fix gcc warnings
- Add bison as BuildRequires (needed to build ajam)
- Compile with -f-no-strict-aliasing to prevent potential issues
  with gcc 4.7
* Fri Jan 27 2012 mcihar@suse.cz
- Fix ColorHug support with new firmware
* Mon Jan 23 2012 kkaempf@suse.com
- ColorHug-sensor-driver.patch: Fix function declaration to improve
  detection of 'perfect black' (via colorhug-users@googlegroups.com)
* Thu Jan 19 2012 fcrozat@suse.com
- remove unused copies of libusb0 and libusbw
- remove unused code from libusb1 directory (windows / macos)
- call autoreconf in %%build
* Mon Jan 16 2012 fcrozat@suse.com
- Add copyright header to specfile
- Clean specfile with spec-cleaner
- Argyllcms is now mostly using AGPLv3, update License tag and use
  SPDX syntax.
- Drop patch which was renaming scanner in documentation (not
  applied anyway).
* Thu Jan 12 2012 kkaempf@suse.com
- Fix Factory build: explicitly BuildRequire autoconf, automake
  and libtool
* Wed Jan 11 2012 kkaempf@suse.com
- Update to 1.3.5
- add Argyll_V1.3.5_autotools.patch covering new files to compile
- add 0001-Add-an-experimental-ColorHug-sensor-driver.patch to
  support 'colorhug' from http://hughski.com (experimental)
* Mon Nov  8 2010 fcrozat@novell.com
- Release 1.3.2 (bug fixes)
- remove argyllcms-1.3.0-include.patch (merged upstream)
* Thu Sep 23 2010 fcrozat@novell.com
- argyllcms-1.3.0-udev151.patch: remove all ACL management from
  udev rules, it is handled by udev package itself (Mandriva)
- argyllcms-1.3.0-include.patch : fix missing includes
* Sun Sep 12 2010 fcrozat@novell.com
- Release 1.3.0
- remove patches argyllcms-1.1.0-bufferoverflow.patch,
  argyllcms-1.1.0-void.patch, argyllcms-1.1.0-strfmt.patch (merged
  upstream)
* Mon Aug  9 2010 fcrozat@novell.com
- Update patch1 with new version from Roland, merging patch10 in it
* Mon Aug  9 2010 fcrozat@novell.com
- Update to 1.2.1
- move back icclib to argyllcms, upstream release are not so frequent as Argyllcms one
- Patch10: allow to use (or not) system icclib
- update patches 8 and 9 with new fixes
* Thu Aug  5 2010 fcrozat@novell.com
- Update to latest release and move icclib to a separate package
* Mon Apr 20 2009 Vladimir Nadvornik <nadvornik@novell.com>
- ported to openSUSE
* Mon Mar 23 2009 Ron Ciesla <limb@jcomserv.net>
- Patch for ICC library CVE-2009-{0583, 0584} by Tim Waugh.
* Sun Feb 22 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild
  * Wed Sep 3 2008 Nicolas Mailhot <nicolas.mailhot at laposte.net>
- 1.0.3-1
  * Mon Sep 1 2008 Nicolas Mailhot <nicolas.mailhot at laposte.net>
- 1.0.2-1
  * Sun Jul 27 2008 Nicolas Mailhot <nicolas.mailhot at laposte.net>
- 1.0.1-1
* Wed Mar 26 2008 Tom "spot" Callaway <tcallawa@redhat.com>
- patch applied for legal reasons
  * Thu Feb 8 2008 Nicolas Mailhot <nicolas.mailhot at laposte.net>
- 0.70-0.8.Beta9
- 0.70-0.8.Beta8
  * Thu Feb 7 2008 Nicolas Mailhot <nicolas.mailhot at laposte.net>
- 0.70-0.7.Beta8
  * Thu Dec 14 2007 Nicolas Mailhot <nicolas.mailhot at laposte.net>
- 0.70-0.6.Beta7
- 0.70-0.5.Beta7
  * Thu Dec 13 2007 Nicolas Mailhot <nicolas.mailhot at laposte.net>
- 0.70-0.4.Beta7
  * Wed Dec 12 2007 Nicolas Mailhot <nicolas.mailhot at laposte.net>
- 0.70-0.3.Beta7
- 0.70-0.2.Beta7
- 0.70-0.1.Beta7
